Documentation
¶
Index ¶
- func IronicClient(ironicEndpoint string, auth AuthConfig, tls TLSConfig) (client *gophercloud.ServiceClient, err error)
- type AuthConfig
- type AuthType
- type AvailableFeatures
- func (af AvailableFeatures) ChooseMicroversion() string
- func (af AvailableFeatures) HasDataImage() bool
- func (af AvailableFeatures) HasDisablePowerOff() bool
- func (af AvailableFeatures) HasFirmwareUpdates() bool
- func (af AvailableFeatures) HasServicing() bool
- func (af AvailableFeatures) HasVirtualMediaGetAPI() bool
- func (af AvailableFeatures) Log(logger logr.Logger)
- type NodeUpdater
- func (nu *NodeUpdater) SetDriverInfoOpts(settings UpdateOptsData, node *nodes.Node) *NodeUpdater
- func (nu *NodeUpdater) SetInstanceInfoOpts(settings UpdateOptsData, node *nodes.Node) *NodeUpdater
- func (nu *NodeUpdater) SetPropertiesOpts(settings UpdateOptsData, node *nodes.Node) *NodeUpdater
- func (nu *NodeUpdater) SetTopLevelOpt(name string, desiredValue, currentValue interface{}) *NodeUpdater
- type TLSConfig
- type UpdateOptsData
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IronicClient ¶
func IronicClient(ironicEndpoint string, auth AuthConfig, tls TLSConfig) (client *gophercloud.ServiceClient, err error)
IronicClient creates a client for Ironic.
Types ¶
type AuthConfig ¶
AuthConfig contains data needed to configure authentication in the client.
func ConfigFromEndpointURL ¶
func ConfigFromEndpointURL(endpointURL string) (endpoint string, auth AuthConfig, err error)
ConfigFromEndpointURL returns an endpoint and an auth config from an endpoint URL that may contain HTTP basic auth credentials.
func LoadAuth ¶
func LoadAuth() (auth AuthConfig, err error)
LoadAuth loads the Ironic configuration from the environment.
type AuthType ¶
type AuthType string
AuthType is the method of authenticating requests to the server.
type AvailableFeatures ¶ added in v0.5.0
type AvailableFeatures struct {
MaxVersion int
}
AvailableFeatures represents features that Ironic API provides. See https://docs.openstack.org/ironic/latest/contributor/webapi-version-history.html
func GetAvailableFeatures ¶ added in v0.5.0
func GetAvailableFeatures(ctx context.Context, client *gophercloud.ServiceClient) (features AvailableFeatures, err error)
func (AvailableFeatures) ChooseMicroversion ¶ added in v0.5.0
func (af AvailableFeatures) ChooseMicroversion() string
func (AvailableFeatures) HasDataImage ¶ added in v0.8.0
func (af AvailableFeatures) HasDataImage() bool
func (AvailableFeatures) HasDisablePowerOff ¶ added in v0.10.0
func (af AvailableFeatures) HasDisablePowerOff() bool
func (AvailableFeatures) HasFirmwareUpdates ¶ added in v0.5.0
func (af AvailableFeatures) HasFirmwareUpdates() bool
func (AvailableFeatures) HasServicing ¶ added in v0.9.0
func (af AvailableFeatures) HasServicing() bool
func (AvailableFeatures) HasVirtualMediaGetAPI ¶ added in v0.10.0
func (af AvailableFeatures) HasVirtualMediaGetAPI() bool
func (AvailableFeatures) Log ¶ added in v0.5.0
func (af AvailableFeatures) Log(logger logr.Logger)
type NodeUpdater ¶ added in v0.8.0
type NodeUpdater struct {
Updates nodes.UpdateOpts
// contains filtered or unexported fields
}
func UpdateOptsBuilder ¶ added in v0.8.0
func UpdateOptsBuilder(logger logr.Logger) *NodeUpdater
func (*NodeUpdater) SetDriverInfoOpts ¶ added in v0.8.0
func (nu *NodeUpdater) SetDriverInfoOpts(settings UpdateOptsData, node *nodes.Node) *NodeUpdater
func (*NodeUpdater) SetInstanceInfoOpts ¶ added in v0.8.0
func (nu *NodeUpdater) SetInstanceInfoOpts(settings UpdateOptsData, node *nodes.Node) *NodeUpdater
func (*NodeUpdater) SetPropertiesOpts ¶ added in v0.8.0
func (nu *NodeUpdater) SetPropertiesOpts(settings UpdateOptsData, node *nodes.Node) *NodeUpdater
func (*NodeUpdater) SetTopLevelOpt ¶ added in v0.8.0
func (nu *NodeUpdater) SetTopLevelOpt(name string, desiredValue, currentValue interface{}) *NodeUpdater
type TLSConfig ¶
type TLSConfig struct {
TrustedCAFile string
ClientCertificateFile string
ClientPrivateKeyFile string
InsecureSkipVerify bool
SkipClientSANVerify bool
}
TLSConfig contains the TLS configuration for the Ironic connection. Using Go default values for this will result in no additional trusted CA certificates and a secure connection. When specifying Certificate and Private key, TLS connection will use client certificate authentication.
type UpdateOptsData ¶ added in v0.8.0
type UpdateOptsData map[string]interface{}